#include <stdio.h>
#include <stdlib.h>
#include "adaptor_api.h"

#define RST		printf("\033[0m")
#define RED		printf("\033[0;31m")
#define GREEN	printf("\033[0;32m")
#define BLUE	printf("\033[0;34m")
#define IRED	printf("\033[1;91m")
#define IGREEN	printf("\033[1;92m")
#define IBLUE	printf("\033[1;94m")
#define BRED	printf("\033[0;101m")
#define BGREEN	printf("\033[0;102m")
#define BBLUE	printf("\033[0;104m")

#define NORMAL	IRED
#define ERR		BRED
#define DATA  RED

#define _D(fmt, ...) do { NORMAL; printf(fmt, ##__VA_ARGS__); RST; } while (0)
#define _DATA(fmt, ...) do {DATA; printf(fmt, ##__VA_ARGS__); RST; } while (0)
#define _E(fmt, ...) do { ERR; printf(fmt, ##__VA_ARGS__); RST; } while (0)


static int __device_reboot(void)
{
	int ret = 0;

	_D("[CLIENT] call __device_reboot~~~~~\n");
	ret = device_reboot();
	_D("[CLIENT] __device_reboot returned(%d) !!!!\n", ret);

	return ret;
}

static int __get_os_info()
{
	int ret = 0;
	int index = 0;
	os_info_s os_info;

	_D("[CLIENT] call os_info_s~~~~~\n");

	ret = get_os_info(&os_info);

	_D("[CLIENT] os_info returned(%d) !!!!\n", ret);

	if (!ret) {
		_DATA("[CLIENT] os_info platformVer = %s\n", os_info.platformVer);
		_DATA("[CLIENT] os_info baseOS version = %s\n", os_info.baseOSVer);
		_DATA("[CLIENT] os_info docker version = %s\n", os_info.dockerVer);
	}
	return ret;
}

static int __get_disk_info()
{
	int ret = 0;
	int index = 0;
	disk_info_s disk_info;

	_D("[CLIENT] call os_info_s~~~~~\n");

	ret = get_disk_info(&disk_info);

	_D("[CLIENT] os_info_s returned(%d) !!!!\n", ret);

	if (!ret) {
		for (index = 0; index < disk_info.count; index++) {
			DATA;
			_DATA("[CLIENT] disk_info[%d] path = %s\n", index, disk_info.disk[index].path);
			_DATA("[CLIENT] disk_info[%d] total = %dM\n", index, disk_info.disk[index].total);
			_DATA("[CLIENT] disk_info[%d] free = %dM\n", index, disk_info.disk[index].free);
			_DATA("[CLIENT] disk_info[%d] used = %dM\n", index, disk_info.disk[index].used);
			_DATA("[CLIENT] disk_info[%d] usedpercent = %.2f%%\n\n", index, (float)disk_info.disk[index].usedpercent/(float)100);
			RST;
		}
	}

	for (index = 0; index < disk_info.count; index++) {
		if (disk_info.disk[index].path)
			free(disk_info.disk[index].path);
	}

	_D("[CLIENT] exit get_disk_info(%d)~~~~~\n", ret);
	return ret;
}

static int __factory_restore(void)
{
	int ret = 0;

	_D("[CLIENT] call __factory_restore~~~~~\n");
	ret = factory_restore();
	_D("[CLIENT] __factory_restore returned(%d) !!!!\n", ret);

	return ret;
}


void *client_thread(void *pv)
{
	int num = 1;
	int ret = 0;

	do {
		_D("\n\n");
		_D("==================================\n");
		_D("       libadatpr test \n");
		_D("==================================\n");
		_D(" 1. device_reboot\n");
		_D(" 2. get_os_info\n");
		_D(" 3. get_disk_info\n");
		_D(" 4. factory_restore\n");
		_D(" 5. exit\n");
		scanf("%d", &num);

		switch (num) {
		case 1:
			ret = __device_reboot();
			break;
		case 2:
			ret = __get_os_info();
			break;
		case 3:
			ret = __get_disk_info();
			break;
		case 4:
			ret = __factory_restore();
			break;
		case 5:
			_D("Exit \n");
			ret = -1;
			break;
		default:
			_D("Not support \n");
			break;
		}
	} while (ret >= 0);

	exit(0);
}

//////////////////////////////////////////////////////////////////
// server main
//////////////////////////////////////////////////////////////////

int main(int argc, char **argv)
{
	pthread_t t_client;
	int status;
	int ret;

	_D("[client] main function...\n");
	ret = pthread_create(&t_client, NULL, &client_thread, (void *)NULL);
	if (ret < 0) {
		_E("[client] __state_mainloop thread create error (ret=%d)\n", ret);
		return -1;
	}
	pthread_join(t_client, (void **)&status);
	_D("[client] closed\n");

	return 1;
}
